# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pygreenfield.api_client import ApiClient


class CustodiansApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get(self, store_id, account_id, payment_method, **kwargs):  # noqa: E501
        """Get a deposit address for custodian  # noqa: E501

        Get a new deposit address for the custodian using the specified payment method (network + crypto code).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get(store_id, account_id, payment_method, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :param str payment_method: The payment method to use for the deposit. Example: \"BTC-OnChain\" or \"BTC-Lightning\" (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get_with_http_info(store_id, account_id, payment_method, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get_with_http_info(store_id, account_id, payment_method, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get_with_http_info(self, store_id, account_id, payment_method, **kwargs):  # noqa: E501
        """Get a deposit address for custodian  # noqa: E501

        Get a new deposit address for the custodian using the specified payment method (network + crypto code).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get_with_http_info(store_id, account_id, payment_method, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :param str payment_method: The payment method to use for the deposit. Example: \"BTC-OnChain\" or \"BTC-Lightning\" (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'account_id', 'payment_method']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get`")  # noqa: E501
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params or
                params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get`")  # noqa: E501
        # verify the required parameter 'payment_method' is set
        if ('payment_method' not in params or
                params['payment_method'] is None):
            raise ValueError("Missing the required parameter `payment_method` when calling `api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']  # noqa: E501
        if 'payment_method' in params:
            path_params['paymentMethod'] = params['payment_method']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts/{accountId}/addresses/{paymentMethod}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_stores_store_id_custodian_accounts_account_id_delete(self, **kwargs):  # noqa: E501
        """Delete store custodian account  # noqa: E501

        Deletes a custodial account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_delete(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_account_id_delete_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_account_id_delete_with_http_info(**kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_account_id_delete_with_http_info(self, **kwargs):  # noqa: E501
        """Delete store custodian account  # noqa: E501

        Deletes a custodial account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_delete_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_account_id_delete" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts/{accountId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_stores_store_id_custodian_accounts_account_id_get(self, store_id, account_id, **kwargs):  # noqa: E501
        """Get store custodian account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_get(store_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID (required)
        :param bool asset_balances: Enable if you want the result to include the 'assetBalances' field. This will make the call slower or could cause the call to fail if the asset balances cannot be loaded (i.e. due to a bad API key).
        :return: CustodianAccountData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_account_id_get_with_http_info(store_id, account_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_account_id_get_with_http_info(store_id, account_id, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_account_id_get_with_http_info(self, store_id, account_id, **kwargs):  # noqa: E501
        """Get store custodian account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_get_with_http_info(store_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID (required)
        :param bool asset_balances: Enable if you want the result to include the 'assetBalances' field. This will make the call slower or could cause the call to fail if the asset balances cannot be loaded (i.e. due to a bad API key).
        :return: CustodianAccountData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'account_id', 'asset_balances']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_account_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_get`")  # noqa: E501
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params or
                params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']  # noqa: E501

        query_params = []
        if 'asset_balances' in params:
            query_params.append(('assetBalances', params['asset_balances']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts/{accountId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustodianAccountData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_stores_store_id_custodian_accounts_account_id_put(self, body, **kwargs):  # noqa: E501
        """Update custodial account  # noqa: E501

        Update custodial account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_put(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustodianAccountRequest body: (required)
        :return: CustodianAccountData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_account_id_put_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_account_id_put_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_account_id_put_with_http_info(self, body, **kwargs):  # noqa: E501
        """Update custodial account  # noqa: E501

        Update custodial account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_put_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustodianAccountRequest body: (required)
        :return: CustodianAccountData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_account_id_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `api_v1_stores_store_id_custodian_accounts_account_id_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts/{accountId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustodianAccountData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post(self, store_id, account_id, **kwargs):  # noqa: E501
        """Trade one asset for another  # noqa: E501

        Trade one asset for another using a market order (=instant purchase with instant result or failure). A suitable asset pair will automatically be selected. If no asset pair is available, the call will fail.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post(store_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :param TradeRequestData body:
        :return: TradeResultData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post_with_http_info(store_id, account_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post_with_http_info(store_id, account_id, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post_with_http_info(self, store_id, account_id, **kwargs):  # noqa: E501
        """Trade one asset for another  # noqa: E501

        Trade one asset for another using a market order (=instant purchase with instant result or failure). A suitable asset pair will automatically be selected. If no asset pair is available, the call will fail.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post_with_http_info(store_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :param TradeRequestData body:
        :return: TradeResultData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'account_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post`")  # noqa: E501
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params or
                params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts/{accountId}/trades/market', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TradeResultData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get(self, store_id, account_id, from_asset, to_asset, **kwargs):  # noqa: E501
        """Get quote for trading one asset for another  # noqa: E501

        Get the current bid and ask price for converting one asset into another.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get(store_id, account_id, from_asset, to_asset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :param str from_asset: The asset to convert. (required)
        :param str to_asset: The asset you want. (required)
        :return: QuoteResultData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get_with_http_info(store_id, account_id, from_asset, to_asset, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get_with_http_info(store_id, account_id, from_asset, to_asset, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get_with_http_info(self, store_id, account_id, from_asset, to_asset, **kwargs):  # noqa: E501
        """Get quote for trading one asset for another  # noqa: E501

        Get the current bid and ask price for converting one asset into another.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get_with_http_info(store_id, account_id, from_asset, to_asset, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :param str from_asset: The asset to convert. (required)
        :param str to_asset: The asset you want. (required)
        :return: QuoteResultData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'account_id', 'from_asset', 'to_asset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get`")  # noqa: E501
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params or
                params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get`")  # noqa: E501
        # verify the required parameter 'from_asset' is set
        if ('from_asset' not in params or
                params['from_asset'] is None):
            raise ValueError("Missing the required parameter `from_asset` when calling `api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get`")  # noqa: E501
        # verify the required parameter 'to_asset' is set
        if ('to_asset' not in params or
                params['to_asset'] is None):
            raise ValueError("Missing the required parameter `to_asset` when calling `api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']  # noqa: E501

        query_params = []
        if 'from_asset' in params:
            query_params.append(('fromAsset', params['from_asset']))  # noqa: E501
        if 'to_asset' in params:
            query_params.append(('toAsset', params['to_asset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts/{accountId}/trades/quote', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QuoteResultData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post(self, body, store_id, account_id, **kwargs):  # noqa: E501
        """Withdraw to store wallet  # noqa: E501

        Withdraw an asset to your store wallet.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post(body, store_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WithdrawalRequestData body: (required)
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :return: WithdrawalResultData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post_with_http_info(body, store_id, account_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post_with_http_info(body, store_id, account_id, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post_with_http_info(self, body, store_id, account_id, **kwargs):  # noqa: E501
        """Withdraw to store wallet  # noqa: E501

        Withdraw an asset to your store wallet.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post_with_http_info(body, store_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param WithdrawalRequestData body: (required)
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :return: WithdrawalResultData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'store_id', 'account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post`")  # noqa: E501
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post`")  # noqa: E501
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params or
                params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts/{accountId}/withdrawals', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WithdrawalResultData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post(self, store_id, account_id, withdrawal_id, **kwargs):  # noqa: E501
        """Get withdrawal info  # noqa: E501

        Get the details about a past withdrawal.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post(store_id, account_id, withdrawal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :param str withdrawal_id: The Withdrawal ID. (required)
        :return: WithdrawalResultData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post_with_http_info(store_id, account_id, withdrawal_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post_with_http_info(store_id, account_id, withdrawal_id, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post_with_http_info(self, store_id, account_id, withdrawal_id, **kwargs):  # noqa: E501
        """Get withdrawal info  # noqa: E501

        Get the details about a past withdrawal.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post_with_http_info(store_id, account_id, withdrawal_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param str account_id: The Custodian Account ID. (required)
        :param str withdrawal_id: The Withdrawal ID. (required)
        :return: WithdrawalResultData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'account_id', 'withdrawal_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post`")  # noqa: E501
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params or
                params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post`")  # noqa: E501
        # verify the required parameter 'withdrawal_id' is set
        if ('withdrawal_id' not in params or
                params['withdrawal_id'] is None):
            raise ValueError("Missing the required parameter `withdrawal_id` when calling `api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']  # noqa: E501
        if 'withdrawal_id' in params:
            path_params['withdrawalId'] = params['withdrawal_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts/{accountId}/withdrawals/{withdrawalId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WithdrawalResultData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_stores_store_id_custodian_accounts_get(self, store_id, **kwargs):  # noqa: E501
        """List store custodian accounts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_get(store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param bool asset_balances: Enable if you want the result to include the 'assetBalances' field. This will make the call slower or could cause the call to fail if the asset balances cannot be loaded (i.e. due to a bad API key).
        :return: list[CustodianAccountData]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_get_with_http_info(store_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_get_with_http_info(store_id, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_get_with_http_info(self, store_id, **kwargs):  # noqa: E501
        """List store custodian accounts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_get_with_http_info(store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The Store ID (required)
        :param bool asset_balances: Enable if you want the result to include the 'assetBalances' field. This will make the call slower or could cause the call to fail if the asset balances cannot be loaded (i.e. due to a bad API key).
        :return: list[CustodianAccountData]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'asset_balances']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `api_v1_stores_store_id_custodian_accounts_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501

        query_params = []
        if 'asset_balances' in params:
            query_params.append(('assetBalances', params['asset_balances']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CustodianAccountData]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_stores_store_id_custodian_accounts_post(self, body, **kwargs):  # noqa: E501
        """Add a custodial account to a store.  # noqa: E501

        Add a custodial account to a store.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustodianAccountRequest body: (required)
        :return: CustodianAccountData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_stores_store_id_custodian_accounts_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_stores_store_id_custodian_accounts_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def api_v1_stores_store_id_custodian_accounts_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """Add a custodial account to a store.  # noqa: E501

        Add a custodial account to a store.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_stores_store_id_custodian_accounts_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCustodianAccountRequest body: (required)
        :return: CustodianAccountData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_stores_store_id_custodian_accounts_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `api_v1_stores_store_id_custodian_accounts_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/custodian-accounts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CustodianAccountData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def custodians_get_supported_custodians(self, **kwargs):  # noqa: E501
        """List supported custodians  # noqa: E501

        List all supported custodians for the BTCPay instance. You can install plugins to add more custodians.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.custodians_get_supported_custodians(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CustodianData]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.custodians_get_supported_custodians_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.custodians_get_supported_custodians_with_http_info(**kwargs)  # noqa: E501
            return data

    def custodians_get_supported_custodians_with_http_info(self, **kwargs):  # noqa: E501
        """List supported custodians  # noqa: E501

        List all supported custodians for the BTCPay instance. You can install plugins to add more custodians.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.custodians_get_supported_custodians_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[CustodianData]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method custodians_get_supported_custodians" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/custodians', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CustodianData]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pygreenfield.api_client import ApiClient


class StoreWalletOnChainApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def store_on_chain_wallets_create_on_chain_transaction(self, body, store_id, crypto_code, **kwargs):  # noqa: E501
        """Create store on-chain wallet transaction  # noqa: E501

        Create store on-chain wallet transaction  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_create_on_chain_transaction(body, store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateOnChainTransactionRequest body: (required)
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet (required)
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_on_chain_wallets_create_on_chain_transaction_with_http_info(body, store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.store_on_chain_wallets_create_on_chain_transaction_with_http_info(body, store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def store_on_chain_wallets_create_on_chain_transaction_with_http_info(self, body, store_id, crypto_code, **kwargs):  # noqa: E501
        """Create store on-chain wallet transaction  # noqa: E501

        Create store on-chain wallet transaction  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_create_on_chain_transaction_with_http_info(body, store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateOnChainTransactionRequest body: (required)
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet (required)
        :return: InlineResponse2003
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'store_id', 'crypto_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_on_chain_wallets_create_on_chain_transaction" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `store_on_chain_wallets_create_on_chain_transaction`")  # noqa: E501
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_on_chain_wallets_create_on_chain_transaction`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_on_chain_wallets_create_on_chain_transaction`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/transactions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2003',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_on_chain_wallets_get_on_chain_fee_rate(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet fee rate  # noqa: E501

        Get wallet onchain fee rate  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_get_on_chain_fee_rate(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :param float block_target: The number of blocks away you are willing to target for confirmation. Defaults to the wallet's configured `RecommendedFeeBlockTarget`
        :return: OnChainWalletFeeRateData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_on_chain_wallets_get_on_chain_fee_rate_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.store_on_chain_wallets_get_on_chain_fee_rate_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def store_on_chain_wallets_get_on_chain_fee_rate_with_http_info(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet fee rate  # noqa: E501

        Get wallet onchain fee rate  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_get_on_chain_fee_rate_with_http_info(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :param float block_target: The number of blocks away you are willing to target for confirmation. Defaults to the wallet's configured `RecommendedFeeBlockTarget`
        :return: OnChainWalletFeeRateData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'crypto_code', 'block_target']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_on_chain_wallets_get_on_chain_fee_rate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_on_chain_wallets_get_on_chain_fee_rate`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_on_chain_wallets_get_on_chain_fee_rate`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []
        if 'block_target' in params:
            query_params.append(('blockTarget', params['block_target']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/feerate', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OnChainWalletFeeRateData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_on_chain_wallets_get_on_chain_wallet_receive_address(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet address  # noqa: E501

        Get or generate address for wallet  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_get_on_chain_wallet_receive_address(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :param bool force_generate: Whether to generate a new address for this request even if the previous one was not used
        :return: OnChainWalletAddressData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_on_chain_wallets_get_on_chain_wallet_receive_address_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.store_on_chain_wallets_get_on_chain_wallet_receive_address_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def store_on_chain_wallets_get_on_chain_wallet_receive_address_with_http_info(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet address  # noqa: E501

        Get or generate address for wallet  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_get_on_chain_wallet_receive_address_with_http_info(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :param bool force_generate: Whether to generate a new address for this request even if the previous one was not used
        :return: OnChainWalletAddressData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'crypto_code', 'force_generate']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_on_chain_wallets_get_on_chain_wallet_receive_address" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_on_chain_wallets_get_on_chain_wallet_receive_address`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_on_chain_wallets_get_on_chain_wallet_receive_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []
        if 'force_generate' in params:
            query_params.append(('forceGenerate', params['force_generate']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/address', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OnChainWalletAddressData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_on_chain_wallets_get_on_chain_wallet_transaction(self, store_id, crypto_code, transaction_id, **kwargs):  # noqa: E501
        """Get store on-chain wallet transaction  # noqa: E501

        Get store on-chain wallet transaction  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_get_on_chain_wallet_transaction(store_id, crypto_code, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet to fetch (required)
        :param str transaction_id: The transaction id to fetch (required)
        :return: OnChainWalletTransactionData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_on_chain_wallets_get_on_chain_wallet_transaction_with_http_info(store_id, crypto_code, transaction_id, **kwargs)  # noqa: E501
        else:
            (data) = self.store_on_chain_wallets_get_on_chain_wallet_transaction_with_http_info(store_id, crypto_code, transaction_id, **kwargs)  # noqa: E501
            return data

    def store_on_chain_wallets_get_on_chain_wallet_transaction_with_http_info(self, store_id, crypto_code, transaction_id, **kwargs):  # noqa: E501
        """Get store on-chain wallet transaction  # noqa: E501

        Get store on-chain wallet transaction  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_get_on_chain_wallet_transaction_with_http_info(store_id, crypto_code, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet to fetch (required)
        :param str transaction_id: The transaction id to fetch (required)
        :return: OnChainWalletTransactionData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'crypto_code', 'transaction_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_on_chain_wallets_get_on_chain_wallet_transaction" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_on_chain_wallets_get_on_chain_wallet_transaction`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_on_chain_wallets_get_on_chain_wallet_transaction`")  # noqa: E501
        # verify the required parameter 'transaction_id' is set
        if ('transaction_id' not in params or
                params['transaction_id'] is None):
            raise ValueError("Missing the required parameter `transaction_id` when calling `store_on_chain_wallets_get_on_chain_wallet_transaction`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501
        if 'transaction_id' in params:
            path_params['transactionId'] = params['transaction_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/transactions/{transactionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OnChainWalletTransactionData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_on_chain_wallets_get_on_chain_wallet_utx_os(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet UTXOS  # noqa: E501

        Get store on-chain wallet utxos  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_get_on_chain_wallet_utx_os(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet to fetch (required)
        :return: list[OnChainWalletUTXOData]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_on_chain_wallets_get_on_chain_wallet_utx_os_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.store_on_chain_wallets_get_on_chain_wallet_utx_os_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def store_on_chain_wallets_get_on_chain_wallet_utx_os_with_http_info(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet UTXOS  # noqa: E501

        Get store on-chain wallet utxos  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_get_on_chain_wallet_utx_os_with_http_info(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet to fetch (required)
        :return: list[OnChainWalletUTXOData]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'crypto_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_on_chain_wallets_get_on_chain_wallet_utx_os" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_on_chain_wallets_get_on_chain_wallet_utx_os`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_on_chain_wallets_get_on_chain_wallet_utx_os`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/utxos', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OnChainWalletUTXOData]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_on_chain_wallets_patch_on_chain_wallet_transaction(self, body, store_id, crypto_code, transaction_id, **kwargs):  # noqa: E501
        """Patch store on-chain wallet transaction info  # noqa: E501

        Patch store on-chain wallet transaction info  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_patch_on_chain_wallet_transaction(body, store_id, crypto_code, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PatchOnChainTransactionRequest body: (required)
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet to fetch (required)
        :param str transaction_id: The transaction id to fetch (required)
        :return: OnChainWalletTransactionData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_on_chain_wallets_patch_on_chain_wallet_transaction_with_http_info(body, store_id, crypto_code, transaction_id, **kwargs)  # noqa: E501
        else:
            (data) = self.store_on_chain_wallets_patch_on_chain_wallet_transaction_with_http_info(body, store_id, crypto_code, transaction_id, **kwargs)  # noqa: E501
            return data

    def store_on_chain_wallets_patch_on_chain_wallet_transaction_with_http_info(self, body, store_id, crypto_code, transaction_id, **kwargs):  # noqa: E501
        """Patch store on-chain wallet transaction info  # noqa: E501

        Patch store on-chain wallet transaction info  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_patch_on_chain_wallet_transaction_with_http_info(body, store_id, crypto_code, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PatchOnChainTransactionRequest body: (required)
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet to fetch (required)
        :param str transaction_id: The transaction id to fetch (required)
        :return: OnChainWalletTransactionData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'store_id', 'crypto_code', 'transaction_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_on_chain_wallets_patch_on_chain_wallet_transaction" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `store_on_chain_wallets_patch_on_chain_wallet_transaction`")  # noqa: E501
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_on_chain_wallets_patch_on_chain_wallet_transaction`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_on_chain_wallets_patch_on_chain_wallet_transaction`")  # noqa: E501
        # verify the required parameter 'transaction_id' is set
        if ('transaction_id' not in params or
                params['transaction_id'] is None):
            raise ValueError("Missing the required parameter `transaction_id` when calling `store_on_chain_wallets_patch_on_chain_wallet_transaction`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501
        if 'transaction_id' in params:
            path_params['transactionId'] = params['transaction_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/transactions/{transactionId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OnChainWalletTransactionData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_on_chain_wallets_show_on_chain_wallet_overview(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet overview  # noqa: E501

        View information about the specified wallet  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_show_on_chain_wallet_overview(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :return: OnChainWalletOverviewData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_on_chain_wallets_show_on_chain_wallet_overview_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.store_on_chain_wallets_show_on_chain_wallet_overview_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def store_on_chain_wallets_show_on_chain_wallet_overview_with_http_info(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet overview  # noqa: E501

        View information about the specified wallet  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_show_on_chain_wallet_overview_with_http_info(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :return: OnChainWalletOverviewData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'crypto_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_on_chain_wallets_show_on_chain_wallet_overview" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_on_chain_wallets_show_on_chain_wallet_overview`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_on_chain_wallets_show_on_chain_wallet_overview`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OnChainWalletOverviewData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_on_chain_wallets_show_on_chain_wallet_transactions(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet transactions  # noqa: E501

        Get store on-chain wallet transactions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_show_on_chain_wallet_transactions(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet to fetch (required)
        :param list[TransactionStatus] status_filter: Statuses to filter the transactions with
        :param str label_filter: Transaction label to filter by
        :param int skip: Number of transactions to skip from the start
        :param int limit: Maximum number of transactions to return
        :return: list[OnChainWalletTransactionData]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_on_chain_wallets_show_on_chain_wallet_transactions_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.store_on_chain_wallets_show_on_chain_wallet_transactions_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def store_on_chain_wallets_show_on_chain_wallet_transactions_with_http_info(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """Get store on-chain wallet transactions  # noqa: E501

        Get store on-chain wallet transactions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_show_on_chain_wallet_transactions_with_http_info(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the wallet to fetch (required)
        :param list[TransactionStatus] status_filter: Statuses to filter the transactions with
        :param str label_filter: Transaction label to filter by
        :param int skip: Number of transactions to skip from the start
        :param int limit: Maximum number of transactions to return
        :return: list[OnChainWalletTransactionData]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'crypto_code', 'status_filter', 'label_filter', 'skip', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_on_chain_wallets_show_on_chain_wallet_transactions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_on_chain_wallets_show_on_chain_wallet_transactions`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_on_chain_wallets_show_on_chain_wallet_transactions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []
        if 'status_filter' in params:
            query_params.append(('statusFilter', params['status_filter']))  # noqa: E501
            collection_formats['statusFilter'] = 'multi'  # noqa: E501
        if 'label_filter' in params:
            query_params.append(('labelFilter', params['label_filter']))  # noqa: E501
        if 'skip' in params:
            query_params.append(('skip', params['skip']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/transactions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[OnChainWalletTransactionData]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """UnReserve last store on-chain wallet address  # noqa: E501

        UnReserve address  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
        else:
            (data) = self.store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address_with_http_info(store_id, crypto_code, **kwargs)  # noqa: E501
            return data

    def store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address_with_http_info(self, store_id, crypto_code, **kwargs):  # noqa: E501
        """UnReserve last store on-chain wallet address  # noqa: E501

        UnReserve address  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address_with_http_info(store_id, crypto_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str store_id: The store to fetch (required)
        :param str crypto_code: The crypto code of the payment method to fetch (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['store_id', 'crypto_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address`")  # noqa: E501
        # verify the required parameter 'crypto_code' is set
        if ('crypto_code' not in params or
                params['crypto_code'] is None):
            raise ValueError("Missing the required parameter `crypto_code` when calling `store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501
        if 'crypto_code' in params:
            path_params['cryptoCode'] = params['crypto_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/address', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OnChainWalletTransactionData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'transaction_hash': 'str',
        'comment': 'str',
        'amount': 'str',
        'block_hash': 'str',
        'block_height': 'str',
        'confirmations': 'str',
        'timestamp': 'AllOfOnChainWalletTransactionDataTimestamp',
        'status': 'TransactionStatus',
        'labels': 'list[LabelData]'
    }

    attribute_map = {
        'transaction_hash': 'transactionHash',
        'comment': 'comment',
        'amount': 'amount',
        'block_hash': 'blockHash',
        'block_height': 'blockHeight',
        'confirmations': 'confirmations',
        'timestamp': 'timestamp',
        'status': 'status',
        'labels': 'labels'
    }

    def __init__(self, transaction_hash=None, comment=None, amount=None, block_hash=None, block_height=None, confirmations=None, timestamp=None, status=None, labels=None):  # noqa: E501
        """OnChainWalletTransactionData - a model defined in Swagger"""  # noqa: E501
        self._transaction_hash = None
        self._comment = None
        self._amount = None
        self._block_hash = None
        self._block_height = None
        self._confirmations = None
        self._timestamp = None
        self._status = None
        self._labels = None
        self.discriminator = None
        if transaction_hash is not None:
            self.transaction_hash = transaction_hash
        if comment is not None:
            self.comment = comment
        if amount is not None:
            self.amount = amount
        if block_hash is not None:
            self.block_hash = block_hash
        if block_height is not None:
            self.block_height = block_height
        if confirmations is not None:
            self.confirmations = confirmations
        if timestamp is not None:
            self.timestamp = timestamp
        if status is not None:
            self.status = status
        if labels is not None:
            self.labels = labels

    @property
    def transaction_hash(self):
        """Gets the transaction_hash of this OnChainWalletTransactionData.  # noqa: E501

        The transaction id  # noqa: E501

        :return: The transaction_hash of this OnChainWalletTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._transaction_hash

    @transaction_hash.setter
    def transaction_hash(self, transaction_hash):
        """Sets the transaction_hash of this OnChainWalletTransactionData.

        The transaction id  # noqa: E501

        :param transaction_hash: The transaction_hash of this OnChainWalletTransactionData.  # noqa: E501
        :type: str
        """

        self._transaction_hash = transaction_hash

    @property
    def comment(self):
        """Gets the comment of this OnChainWalletTransactionData.  # noqa: E501

        A comment linked to the transaction  # noqa: E501

        :return: The comment of this OnChainWalletTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this OnChainWalletTransactionData.

        A comment linked to the transaction  # noqa: E501

        :param comment: The comment of this OnChainWalletTransactionData.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def amount(self):
        """Gets the amount of this OnChainWalletTransactionData.  # noqa: E501

        The amount the wallet balance changed with this transaction  # noqa: E501

        :return: The amount of this OnChainWalletTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this OnChainWalletTransactionData.

        The amount the wallet balance changed with this transaction  # noqa: E501

        :param amount: The amount of this OnChainWalletTransactionData.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def block_hash(self):
        """Gets the block_hash of this OnChainWalletTransactionData.  # noqa: E501

        The hash of the block that confirmed this transaction. Null if still unconfirmed.  # noqa: E501

        :return: The block_hash of this OnChainWalletTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._block_hash

    @block_hash.setter
    def block_hash(self, block_hash):
        """Sets the block_hash of this OnChainWalletTransactionData.

        The hash of the block that confirmed this transaction. Null if still unconfirmed.  # noqa: E501

        :param block_hash: The block_hash of this OnChainWalletTransactionData.  # noqa: E501
        :type: str
        """

        self._block_hash = block_hash

    @property
    def block_height(self):
        """Gets the block_height of this OnChainWalletTransactionData.  # noqa: E501

        The height of the block that confirmed this transaction. Null if still unconfirmed.  # noqa: E501

        :return: The block_height of this OnChainWalletTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._block_height

    @block_height.setter
    def block_height(self, block_height):
        """Sets the block_height of this OnChainWalletTransactionData.

        The height of the block that confirmed this transaction. Null if still unconfirmed.  # noqa: E501

        :param block_height: The block_height of this OnChainWalletTransactionData.  # noqa: E501
        :type: str
        """

        self._block_height = block_height

    @property
    def confirmations(self):
        """Gets the confirmations of this OnChainWalletTransactionData.  # noqa: E501

        The number of confirmations for this transaction  # noqa: E501

        :return: The confirmations of this OnChainWalletTransactionData.  # noqa: E501
        :rtype: str
        """
        return self._confirmations

    @confirmations.setter
    def confirmations(self, confirmations):
        """Sets the confirmations of this OnChainWalletTransactionData.

        The number of confirmations for this transaction  # noqa: E501

        :param confirmations: The confirmations of this OnChainWalletTransactionData.  # noqa: E501
        :type: str
        """

        self._confirmations = confirmations

    @property
    def timestamp(self):
        """Gets the timestamp of this OnChainWalletTransactionData.  # noqa: E501

        The time of the transaction  # noqa: E501

        :return: The timestamp of this OnChainWalletTransactionData.  # noqa: E501
        :rtype: AllOfOnChainWalletTransactionDataTimestamp
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this OnChainWalletTransactionData.

        The time of the transaction  # noqa: E501

        :param timestamp: The timestamp of this OnChainWalletTransactionData.  # noqa: E501
        :type: AllOfOnChainWalletTransactionDataTimestamp
        """

        self._timestamp = timestamp

    @property
    def status(self):
        """Gets the status of this OnChainWalletTransactionData.  # noqa: E501


        :return: The status of this OnChainWalletTransactionData.  # noqa: E501
        :rtype: TransactionStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this OnChainWalletTransactionData.


        :param status: The status of this OnChainWalletTransactionData.  # noqa: E501
        :type: TransactionStatus
        """

        self._status = status

    @property
    def labels(self):
        """Gets the labels of this OnChainWalletTransactionData.  # noqa: E501

        Labels linked to this transaction  # noqa: E501

        :return: The labels of this OnChainWalletTransactionData.  # noqa: E501
        :rtype: list[LabelData]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this OnChainWalletTransactionData.

        Labels linked to this transaction  # noqa: E501

        :param labels: The labels of this OnChainWalletTransactionData.  # noqa: E501
        :type: list[LabelData]
        """

        self._labels = labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OnChainWalletTransactionData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OnChainWalletTransactionData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.users_api import UsersApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_users_get(self):
        """Test case for api_v1_users_get

        Get all users  # noqa: E501
        """
        pass

    def test_api_v1_users_id_or_email_delete(self):
        """Test case for api_v1_users_id_or_email_delete

        Delete user  # noqa: E501
        """
        pass

    def test_api_v1_users_id_or_email_get(self):
        """Test case for api_v1_users_id_or_email_get

        Get user by ID or Email  # noqa: E501
        """
        pass

    def test_api_v1_users_id_or_email_lock_delete(self):
        """Test case for api_v1_users_id_or_email_lock_delete

        Toggle user  # noqa: E501
        """
        pass

    def test_api_v1_users_post(self):
        """Test case for api_v1_users_post

        Create user  # noqa: E501
        """
        pass

    def test_users_delete_current_user(self):
        """Test case for users_delete_current_user

        Deletes user profile  # noqa: E501
        """
        pass

    def test_users_get_current_user(self):
        """Test case for users_get_current_user

        Get current user information  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustodianData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'str',
        'label': 'str',
        'depositable_payment_methods': 'list',
        'withdrawable_payment_methods': 'list',
        'tradable_asset_pairs': 'list'
    }

    attribute_map = {
        'code': 'code',
        'label': 'label',
        'depositable_payment_methods': 'depositablePaymentMethods',
        'withdrawable_payment_methods': 'withdrawablePaymentMethods',
        'tradable_asset_pairs': 'tradableAssetPairs'
    }

    def __init__(self, code=None, label=None, depositable_payment_methods=None, withdrawable_payment_methods=None, tradable_asset_pairs=None):  # noqa: E501
        """CustodianData - a model defined in Swagger"""  # noqa: E501
        self._code = None
        self._label = None
        self._depositable_payment_methods = None
        self._withdrawable_payment_methods = None
        self._tradable_asset_pairs = None
        self.discriminator = None
        if code is not None:
            self.code = code
        if label is not None:
            self.label = label
        if depositable_payment_methods is not None:
            self.depositable_payment_methods = depositable_payment_methods
        if withdrawable_payment_methods is not None:
            self.withdrawable_payment_methods = withdrawable_payment_methods
        if tradable_asset_pairs is not None:
            self.tradable_asset_pairs = tradable_asset_pairs

    @property
    def code(self):
        """Gets the code of this CustodianData.  # noqa: E501

        The unique code of the custodian.  # noqa: E501

        :return: The code of this CustodianData.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this CustodianData.

        The unique code of the custodian.  # noqa: E501

        :param code: The code of this CustodianData.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def label(self):
        """Gets the label of this CustodianData.  # noqa: E501

        The name of the custodian.  # noqa: E501

        :return: The label of this CustodianData.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this CustodianData.

        The name of the custodian.  # noqa: E501

        :param label: The label of this CustodianData.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def depositable_payment_methods(self):
        """Gets the depositable_payment_methods of this CustodianData.  # noqa: E501

        A list of payment methods (crypto code + network) you can deposit to the custodian.  # noqa: E501

        :return: The depositable_payment_methods of this CustodianData.  # noqa: E501
        :rtype: list
        """
        return self._depositable_payment_methods

    @depositable_payment_methods.setter
    def depositable_payment_methods(self, depositable_payment_methods):
        """Sets the depositable_payment_methods of this CustodianData.

        A list of payment methods (crypto code + network) you can deposit to the custodian.  # noqa: E501

        :param depositable_payment_methods: The depositable_payment_methods of this CustodianData.  # noqa: E501
        :type: list
        """

        self._depositable_payment_methods = depositable_payment_methods

    @property
    def withdrawable_payment_methods(self):
        """Gets the withdrawable_payment_methods of this CustodianData.  # noqa: E501

        A list of payment methods (crypto code + network) you can withdraw from the custodian.  # noqa: E501

        :return: The withdrawable_payment_methods of this CustodianData.  # noqa: E501
        :rtype: list
        """
        return self._withdrawable_payment_methods

    @withdrawable_payment_methods.setter
    def withdrawable_payment_methods(self, withdrawable_payment_methods):
        """Sets the withdrawable_payment_methods of this CustodianData.

        A list of payment methods (crypto code + network) you can withdraw from the custodian.  # noqa: E501

        :param withdrawable_payment_methods: The withdrawable_payment_methods of this CustodianData.  # noqa: E501
        :type: list
        """

        self._withdrawable_payment_methods = withdrawable_payment_methods

    @property
    def tradable_asset_pairs(self):
        """Gets the tradable_asset_pairs of this CustodianData.  # noqa: E501

        A list of tradable asset pairs, or NULL if the custodian cannot trades/convert assets.  # noqa: E501

        :return: The tradable_asset_pairs of this CustodianData.  # noqa: E501
        :rtype: list
        """
        return self._tradable_asset_pairs

    @tradable_asset_pairs.setter
    def tradable_asset_pairs(self, tradable_asset_pairs):
        """Sets the tradable_asset_pairs of this CustodianData.

        A list of tradable asset pairs, or NULL if the custodian cannot trades/convert assets.  # noqa: E501

        :param tradable_asset_pairs: The tradable_asset_pairs of this CustodianData.  # noqa: E501
        :type: list
        """

        self._tradable_asset_pairs = tradable_asset_pairs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustodianData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustodianData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReceiptOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled': 'bool',
        'show_qr': 'bool',
        'show_payments': 'bool'
    }

    attribute_map = {
        'enabled': 'enabled',
        'show_qr': 'showQR',
        'show_payments': 'showPayments'
    }

    def __init__(self, enabled=None, show_qr=None, show_payments=None):  # noqa: E501
        """ReceiptOptions - a model defined in Swagger"""  # noqa: E501
        self._enabled = None
        self._show_qr = None
        self._show_payments = None
        self.discriminator = None
        if enabled is not None:
            self.enabled = enabled
        if show_qr is not None:
            self.show_qr = show_qr
        if show_payments is not None:
            self.show_payments = show_payments

    @property
    def enabled(self):
        """Gets the enabled of this ReceiptOptions.  # noqa: E501

        A public page will be accessible once the invoice is settled. If null or unspecified, it will fallback to the store's settings. (The default store settings is true)  # noqa: E501

        :return: The enabled of this ReceiptOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ReceiptOptions.

        A public page will be accessible once the invoice is settled. If null or unspecified, it will fallback to the store's settings. (The default store settings is true)  # noqa: E501

        :param enabled: The enabled of this ReceiptOptions.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def show_qr(self):
        """Gets the show_qr of this ReceiptOptions.  # noqa: E501

        Show the QR code of the receipt in the public receipt page. If null or unspecified, it will fallback to the store's settings. (The default store setting is true)  # noqa: E501

        :return: The show_qr of this ReceiptOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_qr

    @show_qr.setter
    def show_qr(self, show_qr):
        """Sets the show_qr of this ReceiptOptions.

        Show the QR code of the receipt in the public receipt page. If null or unspecified, it will fallback to the store's settings. (The default store setting is true)  # noqa: E501

        :param show_qr: The show_qr of this ReceiptOptions.  # noqa: E501
        :type: bool
        """

        self._show_qr = show_qr

    @property
    def show_payments(self):
        """Gets the show_payments of this ReceiptOptions.  # noqa: E501

        Show the payment list in the public receipt page. If null or unspecified, it will fallback to the store's settings. (The default store setting is true)  # noqa: E501

        :return: The show_payments of this ReceiptOptions.  # noqa: E501
        :rtype: bool
        """
        return self._show_payments

    @show_payments.setter
    def show_payments(self, show_payments):
        """Sets the show_payments of this ReceiptOptions.

        Show the payment list in the public receipt page. If null or unspecified, it will fallback to the store's settings. (The default store setting is true)  # noqa: E501

        :param show_payments: The show_payments of this ReceiptOptions.  # noqa: E501
        :type: bool
        """

        self._show_payments = show_payments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReceiptOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReceiptOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LightningNetworkPaymentMethodBaseData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'connection_string': 'str',
        'disable_bolt11_payment_option': 'bool'
    }

    attribute_map = {
        'connection_string': 'connectionString',
        'disable_bolt11_payment_option': 'disableBOLT11PaymentOption'
    }

    def __init__(self, connection_string=None, disable_bolt11_payment_option=None):  # noqa: E501
        """LightningNetworkPaymentMethodBaseData - a model defined in Swagger"""  # noqa: E501
        self._connection_string = None
        self._disable_bolt11_payment_option = None
        self.discriminator = None
        if connection_string is not None:
            self.connection_string = connection_string
        if disable_bolt11_payment_option is not None:
            self.disable_bolt11_payment_option = disable_bolt11_payment_option

    @property
    def connection_string(self):
        """Gets the connection_string of this LightningNetworkPaymentMethodBaseData.  # noqa: E501

        The lightning connection string. Set to 'Internal Node' to use the internal node. (See [this doc](https://github.com/btcpayserver/BTCPayServer.Lightning/blob/master/README.md#examples) for some example)  # noqa: E501

        :return: The connection_string of this LightningNetworkPaymentMethodBaseData.  # noqa: E501
        :rtype: str
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """Sets the connection_string of this LightningNetworkPaymentMethodBaseData.

        The lightning connection string. Set to 'Internal Node' to use the internal node. (See [this doc](https://github.com/btcpayserver/BTCPayServer.Lightning/blob/master/README.md#examples) for some example)  # noqa: E501

        :param connection_string: The connection_string of this LightningNetworkPaymentMethodBaseData.  # noqa: E501
        :type: str
        """

        self._connection_string = connection_string

    @property
    def disable_bolt11_payment_option(self):
        """Gets the disable_bolt11_payment_option of this LightningNetworkPaymentMethodBaseData.  # noqa: E501

        Whether to disable generation of bolt11 invoices. Useful when wanting to only use LNURL Pay exclusively.  # noqa: E501

        :return: The disable_bolt11_payment_option of this LightningNetworkPaymentMethodBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._disable_bolt11_payment_option

    @disable_bolt11_payment_option.setter
    def disable_bolt11_payment_option(self, disable_bolt11_payment_option):
        """Sets the disable_bolt11_payment_option of this LightningNetworkPaymentMethodBaseData.

        Whether to disable generation of bolt11 invoices. Useful when wanting to only use LNURL Pay exclusively.  # noqa: E501

        :param disable_bolt11_payment_option: The disable_bolt11_payment_option of this LightningNetworkPaymentMethodBaseData.  # noqa: E501
        :type: bool
        """

        self._disable_bolt11_payment_option = disable_bolt11_payment_option

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LightningNetworkPaymentMethodBaseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LightningNetworkPaymentMethodBaseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OffchainBalanceData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'opening': 'str',
        'local': 'str',
        'remote': 'str',
        'closing': 'str'
    }

    attribute_map = {
        'opening': 'opening',
        'local': 'local',
        'remote': 'remote',
        'closing': 'closing'
    }

    def __init__(self, opening=None, local=None, remote=None, closing=None):  # noqa: E501
        """OffchainBalanceData - a model defined in Swagger"""  # noqa: E501
        self._opening = None
        self._local = None
        self._remote = None
        self._closing = None
        self.discriminator = None
        if opening is not None:
            self.opening = opening
        if local is not None:
            self.local = local
        if remote is not None:
            self.remote = remote
        if closing is not None:
            self.closing = closing

    @property
    def opening(self):
        """Gets the opening of this OffchainBalanceData.  # noqa: E501

        The amount of current channel openings in millisatoshi  # noqa: E501

        :return: The opening of this OffchainBalanceData.  # noqa: E501
        :rtype: str
        """
        return self._opening

    @opening.setter
    def opening(self, opening):
        """Sets the opening of this OffchainBalanceData.

        The amount of current channel openings in millisatoshi  # noqa: E501

        :param opening: The opening of this OffchainBalanceData.  # noqa: E501
        :type: str
        """

        self._opening = opening

    @property
    def local(self):
        """Gets the local of this OffchainBalanceData.  # noqa: E501

        The amount that is available on the local end of active channels in millisatoshi  # noqa: E501

        :return: The local of this OffchainBalanceData.  # noqa: E501
        :rtype: str
        """
        return self._local

    @local.setter
    def local(self, local):
        """Sets the local of this OffchainBalanceData.

        The amount that is available on the local end of active channels in millisatoshi  # noqa: E501

        :param local: The local of this OffchainBalanceData.  # noqa: E501
        :type: str
        """

        self._local = local

    @property
    def remote(self):
        """Gets the remote of this OffchainBalanceData.  # noqa: E501

        The amount that is available on the remote end of active channels in millisatoshi  # noqa: E501

        :return: The remote of this OffchainBalanceData.  # noqa: E501
        :rtype: str
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this OffchainBalanceData.

        The amount that is available on the remote end of active channels in millisatoshi  # noqa: E501

        :param remote: The remote of this OffchainBalanceData.  # noqa: E501
        :type: str
        """

        self._remote = remote

    @property
    def closing(self):
        """Gets the closing of this OffchainBalanceData.  # noqa: E501

        The amount of current channel closings in millisatoshi  # noqa: E501

        :return: The closing of this OffchainBalanceData.  # noqa: E501
        :rtype: str
        """
        return self._closing

    @closing.setter
    def closing(self, closing):
        """Sets the closing of this OffchainBalanceData.

        The amount of current channel closings in millisatoshi  # noqa: E501

        :param closing: The closing of this OffchainBalanceData.  # noqa: E501
        :type: str
        """

        self._closing = closing

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OffchainBalanceData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OffchainBalanceData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WithdrawalResultData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset': 'str',
        'payment_method': 'str',
        'ledger_entries': 'list[LedgerEntryData]',
        'withdrawal_id': 'str',
        'account_id': 'str',
        'custodian_code': 'str',
        'status': 'str',
        'transaction_id': 'str',
        'target_address': 'str'
    }

    attribute_map = {
        'asset': 'asset',
        'payment_method': 'paymentMethod',
        'ledger_entries': 'ledgerEntries',
        'withdrawal_id': 'withdrawalId',
        'account_id': 'accountId',
        'custodian_code': 'custodianCode',
        'status': 'status',
        'transaction_id': 'transactionId',
        'target_address': 'targetAddress'
    }

    def __init__(self, asset=None, payment_method=None, ledger_entries=None, withdrawal_id=None, account_id=None, custodian_code=None, status=None, transaction_id=None, target_address=None):  # noqa: E501
        """WithdrawalResultData - a model defined in Swagger"""  # noqa: E501
        self._asset = None
        self._payment_method = None
        self._ledger_entries = None
        self._withdrawal_id = None
        self._account_id = None
        self._custodian_code = None
        self._status = None
        self._transaction_id = None
        self._target_address = None
        self.discriminator = None
        if asset is not None:
            self.asset = asset
        if payment_method is not None:
            self.payment_method = payment_method
        if ledger_entries is not None:
            self.ledger_entries = ledger_entries
        if withdrawal_id is not None:
            self.withdrawal_id = withdrawal_id
        if account_id is not None:
            self.account_id = account_id
        if custodian_code is not None:
            self.custodian_code = custodian_code
        if status is not None:
            self.status = status
        if transaction_id is not None:
            self.transaction_id = transaction_id
        if target_address is not None:
            self.target_address = target_address

    @property
    def asset(self):
        """Gets the asset of this WithdrawalResultData.  # noqa: E501

        The asset that is being withdrawn.  # noqa: E501

        :return: The asset of this WithdrawalResultData.  # noqa: E501
        :rtype: str
        """
        return self._asset

    @asset.setter
    def asset(self, asset):
        """Sets the asset of this WithdrawalResultData.

        The asset that is being withdrawn.  # noqa: E501

        :param asset: The asset of this WithdrawalResultData.  # noqa: E501
        :type: str
        """

        self._asset = asset

    @property
    def payment_method(self):
        """Gets the payment_method of this WithdrawalResultData.  # noqa: E501

        The payment method that is used (crypto code + network).  # noqa: E501

        :return: The payment_method of this WithdrawalResultData.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this WithdrawalResultData.

        The payment method that is used (crypto code + network).  # noqa: E501

        :param payment_method: The payment_method of this WithdrawalResultData.  # noqa: E501
        :type: str
        """

        self._payment_method = payment_method

    @property
    def ledger_entries(self):
        """Gets the ledger_entries of this WithdrawalResultData.  # noqa: E501

        The asset entries that were changed during the withdrawal. The first item is always the withdrawal itself. It could also includes ledger entries for the costs and may include credits or exchange tokens to give a discount.  # noqa: E501

        :return: The ledger_entries of this WithdrawalResultData.  # noqa: E501
        :rtype: list[LedgerEntryData]
        """
        return self._ledger_entries

    @ledger_entries.setter
    def ledger_entries(self, ledger_entries):
        """Sets the ledger_entries of this WithdrawalResultData.

        The asset entries that were changed during the withdrawal. The first item is always the withdrawal itself. It could also includes ledger entries for the costs and may include credits or exchange tokens to give a discount.  # noqa: E501

        :param ledger_entries: The ledger_entries of this WithdrawalResultData.  # noqa: E501
        :type: list[LedgerEntryData]
        """

        self._ledger_entries = ledger_entries

    @property
    def withdrawal_id(self):
        """Gets the withdrawal_id of this WithdrawalResultData.  # noqa: E501

        The unique ID of the withdrawal used by the exchange.  # noqa: E501

        :return: The withdrawal_id of this WithdrawalResultData.  # noqa: E501
        :rtype: str
        """
        return self._withdrawal_id

    @withdrawal_id.setter
    def withdrawal_id(self, withdrawal_id):
        """Sets the withdrawal_id of this WithdrawalResultData.

        The unique ID of the withdrawal used by the exchange.  # noqa: E501

        :param withdrawal_id: The withdrawal_id of this WithdrawalResultData.  # noqa: E501
        :type: str
        """

        self._withdrawal_id = withdrawal_id

    @property
    def account_id(self):
        """Gets the account_id of this WithdrawalResultData.  # noqa: E501

        The unique ID of the custodian account used.  # noqa: E501

        :return: The account_id of this WithdrawalResultData.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this WithdrawalResultData.

        The unique ID of the custodian account used.  # noqa: E501

        :param account_id: The account_id of this WithdrawalResultData.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def custodian_code(self):
        """Gets the custodian_code of this WithdrawalResultData.  # noqa: E501

        The code of the custodian used.  # noqa: E501

        :return: The custodian_code of this WithdrawalResultData.  # noqa: E501
        :rtype: str
        """
        return self._custodian_code

    @custodian_code.setter
    def custodian_code(self, custodian_code):
        """Sets the custodian_code of this WithdrawalResultData.

        The code of the custodian used.  # noqa: E501

        :param custodian_code: The custodian_code of this WithdrawalResultData.  # noqa: E501
        :type: str
        """

        self._custodian_code = custodian_code

    @property
    def status(self):
        """Gets the status of this WithdrawalResultData.  # noqa: E501

        The status of the withdrawal: 'Queued', 'Complete', 'Failed' or 'Unknown'.  # noqa: E501

        :return: The status of this WithdrawalResultData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WithdrawalResultData.

        The status of the withdrawal: 'Queued', 'Complete', 'Failed' or 'Unknown'.  # noqa: E501

        :param status: The status of this WithdrawalResultData.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def transaction_id(self):
        """Gets the transaction_id of this WithdrawalResultData.  # noqa: E501

        The transaction ID on the blockchain once the withdrawal has been executed.  # noqa: E501

        :return: The transaction_id of this WithdrawalResultData.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this WithdrawalResultData.

        The transaction ID on the blockchain once the withdrawal has been executed.  # noqa: E501

        :param transaction_id: The transaction_id of this WithdrawalResultData.  # noqa: E501
        :type: str
        """

        self._transaction_id = transaction_id

    @property
    def target_address(self):
        """Gets the target_address of this WithdrawalResultData.  # noqa: E501

        The address where the funds were sent to once the withdrawal has been executed.  # noqa: E501

        :return: The target_address of this WithdrawalResultData.  # noqa: E501
        :rtype: str
        """
        return self._target_address

    @target_address.setter
    def target_address(self, target_address):
        """Sets the target_address of this WithdrawalResultData.

        The address where the funds were sent to once the withdrawal has been executed.  # noqa: E501

        :param target_address: The target_address of this WithdrawalResultData.  # noqa: E501
        :type: str
        """

        self._target_address = target_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WithdrawalResultData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WithdrawalResultData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from pygreenfield.models.payment_request_base_data import PaymentRequestBaseData  # noqa: F401,E501

class PaymentRequestData(PaymentRequestBaseData):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'store_id': 'str',
        'status': 'str',
        'created_time': 'object'
    }
    if hasattr(PaymentRequestBaseData, "swagger_types"):
        swagger_types.update(PaymentRequestBaseData.swagger_types)

    attribute_map = {
        'id': 'id',
        'store_id': 'storeId',
        'status': 'status',
        'created_time': 'createdTime'
    }
    if hasattr(PaymentRequestBaseData, "attribute_map"):
        attribute_map.update(PaymentRequestBaseData.attribute_map)

    def __init__(self, id=None, store_id=None, status=None, created_time=None, *args, **kwargs):  # noqa: E501
        """PaymentRequestData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._store_id = None
        self._status = None
        self._created_time = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if store_id is not None:
            self.store_id = store_id
        if status is not None:
            self.status = status
        if created_time is not None:
            self.created_time = created_time
        PaymentRequestBaseData.__init__(self, *args, **kwargs)

    @property
    def id(self):
        """Gets the id of this PaymentRequestData.  # noqa: E501

        The id of the payment request  # noqa: E501

        :return: The id of this PaymentRequestData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentRequestData.

        The id of the payment request  # noqa: E501

        :param id: The id of this PaymentRequestData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def store_id(self):
        """Gets the store_id of this PaymentRequestData.  # noqa: E501

        The store identifier that the payment request belongs to  # noqa: E501

        :return: The store_id of this PaymentRequestData.  # noqa: E501
        :rtype: str
        """
        return self._store_id

    @store_id.setter
    def store_id(self, store_id):
        """Sets the store_id of this PaymentRequestData.

        The store identifier that the payment request belongs to  # noqa: E501

        :param store_id: The store_id of this PaymentRequestData.  # noqa: E501
        :type: str
        """

        self._store_id = store_id

    @property
    def status(self):
        """Gets the status of this PaymentRequestData.  # noqa: E501

        The status of the payment request  # noqa: E501

        :return: The status of this PaymentRequestData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PaymentRequestData.

        The status of the payment request  # noqa: E501

        :param status: The status of this PaymentRequestData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Pending", "Completed", "Expired"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def created_time(self):
        """Gets the created_time of this PaymentRequestData.  # noqa: E501

        The creation date of the payment request  # noqa: E501

        :return: The created_time of this PaymentRequestData.  # noqa: E501
        :rtype: object
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this PaymentRequestData.

        The creation date of the payment request  # noqa: E501

        :param created_time: The created_time of this PaymentRequestData.  # noqa: E501
        :type: object
        """

        self._created_time = created_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentRequestData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentRequestData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
